import { useAccountStore } from "@/stores/account";
import axios from "axios";

export type FetchParams = {
	method?: string;
	body?: any;
};

export default async function apiFetch<T>(path: string, params: FetchParams = {}): Promise<T> {
	const method = params.method ?? "GET";
	const token = useAccountStore().token;
	const headers = token
		? {
				Authorization: token,
		  }
		: {};

	try {
		const resp = await axios<T>({
			method,
			url: path,
			headers: {
				...headers,
				"Content-Type": "application/json",
			},
			responseType: "json",
			data: params.body || undefined,
		});

		return resp.data;
	} catch (e: any) {
		console.log(`Error fetching "${path}": ${e}`);

		console.log(e);
		console.log(e.response);
		console.log(e.response.data);

		throw e.response.data;
	}
}
